<?php

namespace Drupal\valentine\Controller;

use Drupal\Core\Controller\ControllerBase;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Controller for valentine pages.
 */
class ValentineController extends ControllerBase {

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    $instance = parent::create($container)
      ->setStringTranslation($container->get('string_translation'));

    $instance->entityTypeManager = $container->get('entity_type.manager');

    return $instance;
  }

  /**
   * Provides an add title callback for an entity type.
   *
   * @return string
   *   The title for the entity add page.
   */
  public function addTitle() {
    return $this->title($this->t('Create a valentine'));
  }

  /**
   * Provides a list title callback for an entity type.
   *
   * @return string
   *   The title for the entity list page.
   */
  public function listTitle() {
    return $this->title(
      $this->entityTypeManager()->getDefinition('valentine')
        ->getCollectionLabel()
    );
  }

  /**
   * Provides a generic title callback for an entity type.
   *
   * @param \Drupal\Core\StringTranslation\TranslatableMarkup $text
   *   The title text.
   *
   * @return string
   *   The title for the entity page.
   */
  public function title($text) {
    return '♥ ' . $text . ' ♥';
  }

}
