<?php

namespace Drupal\valentine\Form;

use Drupal\Core\Ajax\AjaxResponse;
use Drupal\Core\Ajax\CloseDialogCommand;
use Drupal\Core\Ajax\MessageCommand;
use Drupal\Core\Entity\ContentEntityForm;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Form handler for the valentine creation form.
 */
class ValentineForm extends ContentEntityForm {

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    $instance = parent::create($container)
      ->setRequestStack($container->get('request_stack'))
      ->setStringTranslation($container->get('string_translation'));

    $instance->setMessenger($container->get('messenger'));

    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  protected function actions(array $form, FormStateInterface $form_state) {
    $element = parent::actions($form, $form_state);

    $element['submit']['#value'] = $this->t('Send');
    $element['submit']['#ajax'] = ['callback' => [$this, 'ajaxCallback']];

    return $element;
  }

  /**
   * Ajax callback to close the modal and show a message.
   *
   * @return \Drupal\Core\Ajax\AjaxResponse
   *   The AJAX response.
   */
  public function ajaxCallback() {
    return (new AjaxResponse())
      ->addCommand(new CloseDialogCommand())
      ->addCommand(new MessageCommand($this->message()));
  }

  /**
   * Gets message.
   *
   * @return \Drupal\Core\StringTranslation\TranslatableMarkup
   *   The translatable markup.
   */
  protected function message() {
    /** @var \Drupal\valentine\Entity\ValentineInterface $valentine */
    $valentine = $this->entity;

    return $this->t(
      'The valentine for %name has been sent.',
      ['%name' => $valentine->getOwner()->getDisplayName()]
    );
  }

  /**
   * {@inheritdoc}
   */
  public function save(array $form, FormStateInterface $form_state) {
    if (!$this->getRequest()->isXmlHttpRequest()) {
      $this->messenger()->addStatus($this->message());
    }

    return parent::save($form, $form_state);
  }

}
